@@ -52,7 +52,7 @@ class KGET_EXPORT DataSourceFactory : public QObject
         /**
          * The capabilities the DataSourceFactory supports
          */
-        Transfer::Capabilities capabilities() const;
+        Transfer::Capabilities capabilities() const {return m_capabilities;}
 
         /**
          * Deletes the created (downloadInitialized() is true) file if the download was not finished
@@ -68,22 +68,23 @@ class KGET_EXPORT DataSourceFactory : public QObject
 
         void start();
         void stop();
-        KIO::filesize_t size() const;
-        KIO::filesize_t downloadedSize() const;
-        ulong currentSpeed() const;
+        KIO::filesize_t size() const {return m_size;}
+        KIO::filesize_t downloadedSize() const {return m_downloadedSize;}
+        ulong currentSpeed() const {return m_speed;}
+        ulong percent() const {return m_percent;}
 
-        KUrl dest() const;
+        KUrl dest() const {return m_dest;}
 
         /**
          * The maximum number of mirrors that will be used for downloading, default is 3
          */
-        int maxMirrorsUsed() const;
+        int maxMirrorsUsed() const {return m_maxMirrorsUsed;}
 
         /**
          * Change the maximum number off mirrors that will be used for downloading,
          * if the download started already some mirrors might be added or removed automatically
          */
-        void setMaxMirrorsUsed(int maxMirrorsUsed);
+        void setMaxMirrorsUsed(int maxMirrorsUsed) {m_maxMirrorsUsed = maxMirrorsUsed;}
 
         /**
          * Add a mirror that can be used for downloading
@@ -137,7 +138,7 @@ class KGET_EXPORT DataSourceFactory : public QObject
          * true by default
          * @note can be used for multiple datasourcefactory downloads
          */
-        bool doDownload() const;
+        bool doDownload() const {return m_doDownload;}
 
         /**
          * Set if the datasourcefactory should download the file or not,
@@ -148,14 +149,14 @@ class KGET_EXPORT DataSourceFactory : public QObject
 
         bool setNewDestination(const KUrl &newDest);
 
-        Job::Status status() const;
+        Job::Status status() const {return m_status;}
 
         /**
          * @return true if the download was already initialized, i.e. a file has been
          * created and maybe even written to
          * @see deinit()
          */
-        bool downloadInitialized() const;
+        bool downloadInitialized() const {return m_downloadInitialized;}
 
         /**
          * Tries to repair a broken download, via completely redownloading it
@@ -169,11 +170,8 @@ class KGET_EXPORT DataSourceFactory : public QObject
 
     Q_SIGNALS:
         void capabilitiesChanged();
-        void processedSize(KIO::filesize_t size);
-        void totalSize(KIO::filesize_t size);
-        void speed(ulong speed);
-        void percent(ulong percent);
-        void statusChanged(Job::Status status);
+        void dataSourceFactoryChange(Transfer::ChangesFlags change);
+        void log(const QString &message, Transfer::LogLevel logLevel);
 
     public slots:
         void save(const QDomElement &element);
@@ -182,6 +180,8 @@ class KGET_EXPORT DataSourceFactory : public QObject
     private slots:
         void slotUpdateCapabilities();
 
+        void slotRemovedFile();
+
         /**
          * Tries to find the size of the file, automatically called
          * by start if no file size has been specified
@@ -253,6 +253,8 @@ class KGET_EXPORT DataSourceFactory : public QObject
         QList<KIO::filesize_t> m_prevDownloadedSizes;
         KIO::fileoffset_t m_segSize;
         ulong m_speed;
+        ulong m_percent;
+
         /**
          * the cache of data that could not be written yet
          */
